@@ -54,7 +54,11 @@ _ANU_URL: str = "https://qrng.anu.edu.au/API/jsonI.php"
 
 
 def _get_qrand_int64() -> List[int]:
-    """Get quantum random int64s from the ANU API."""
+    """Gets quantum random int64s from the ANU API.
+
+    Raises RuntimeError if the ANU API call is not successful.
+
+    """
     response = requests.get(_ANU_URL, _ANU_PARAMS)
     response.raise_for_status()
     r_json = response.json()
@@ -66,38 +70,48 @@ def _get_qrand_int64() -> List[int]:
             "The 'success' field in the ANU response was False."
         )
         # The status code is 200 when this happens
+    return
 
 
 class _QuantumRandom(pyrandom.Random):
     """Quantum random number generator."""
 
     def __init__(self):
-        """Initialize an instance."""
+        """Initializes an instance of _QuantumRandom."""
         with warnings.catch_warnings():
             warnings.simplefilter("ignore", category=UserWarning)
             super().__init__()
         self._rand_int64 = []
+        return
 
     def fill(self, n: int = 1):
-        """Fill the generator with n batches of 1024 64-bit ints."""
+        """Fills the generator with n batches of 1024 64-bit ints."""
         for _ in range(n):
             self._rand_int64.extend(_get_qrand_int64())
+        return
 
     def random(self) -> float:
-        """Get the next quantum random number in the range [0.0, 1.0)."""
+        """Gets the next quantum random number in the range [0.0, 1.0)."""
         if not self._rand_int64:
             self.fill()
         rand_int64 = self._rand_int64.pop()
-        return rand_int64 / (2 ** 64)
+        return rand_int64 / (2**64)
 
     def seed(self, *args, **kwds) -> None:
-        "Method is ignored. There is no seed for the quantum vacuum."
-        assert self.seed.__doc__ is not None
+        """Method is ignored. There is no seed for the quantum vacuum.
+
+        Raises RuntimeError if docstring for seed does not exist.
+
+        """
+        if self.seed.__doc__ is None:
+            raise RuntimeError("Docstring for seed must exist.")
         warnings.warn(self.seed.__doc__)
+        return
 
     def _notimplemented(self, *args, **kwds) -> NoReturn:
-        "Method should not be called for a quantum random number generator."
+        """Method shouldn't be called for a quantum random number generator."""
         raise NotImplementedError("Quantum source does not have state.")
+        return
 
     getstate = setstate = _notimplemented
 
